jQuery(document).ready(function() {
  $ = jQuery;
  
  // Determine the device pixel ratio of the device
  var dpr = '';
  if (window.devicePixelRatio == undefined) {
    // If devicePixelRatio is not defined, set it to 1
    dpr = 1;
  }
  else {
    // If it is defined, set it as is.
    // For intance, current Google Chrome returns 1, iPhone 4+ returns 2
    dpr = window.devicePixelRatio;
  }
  
  // New Width and Old Width variables to see if screen is growing or shrinking
  var oldWidth = $(window).width();
  var newWidth = 0;
  
  // Loop over each image, and change their width depending on their container's width
  // We use parent width as opposed to image width because image width does not work
  //  reliably in all circumstances. This also allows different images on the page to be
  //  scaled differently and is not dependent on screen size.
  // We swap the next size images in at 95% of the current image's actual width to help 
  //  ensure a smooth flow between images by allowing for a buffer between sizes.
  $('img.borealis').each(function() {
    var parentWidth = $(this).parent().width();
    if (parentWidth >= 238 && parentWidth < 475) {
      borealisImgReplace($(this), 'respondmedium', 'respondlarge');
    }
    else if (parentWidth >= 475 && parentWidth < 950) {
      borealisImgReplace($(this), 'respondlarge', 'respondxl');
    }
    else if (parentWidth >= 950) {
      borealisImgReplace($(this), 'respondxl', 'respondxl2');
    }
    else {
      borealisImgReplace($(this), 'respondsmall', 'respondmedium');
    }
  });
  
  // When the screen is resized, check again!
  $(window).resize(function() {
    newWidth = $(window).width();
    if (newWidth > oldWidth) {
      $('img.borealis').each(function() {
        var parentWidth = $(this).parent().width();
        if (parentWidth >= 238 && parentWidth < 475) {
          borealisImgReplace($(this), 'respondmedium', 'respondlarge');
        }
        else if (parentWidth >= 475 && parentWidth < 950) {
          borealisImgReplace($(this), 'respondlarge', 'respondxl');
        }
        else if (parentWidth >= 950) {
          borealisImgReplace($(this), 'respondxl', 'respondxl2');
        }
        else {
          borealisImgReplace($(this), 'respondsmall', 'respondmedium');
        }
      });
    }
    oldWidth = newWidth;
  });
  
  // Image Replacement Function
  function borealisImgReplace(obj, regularSize, doubleSize) {
    var src = obj.attr('src');
    // Only do SRC replacement if the image's SRC has Borealis in it.
    if (src.indexOf('borealis_') != -1) {
      // Split the SRC up, we're going to be taking parts.
      src = src.split('/');
      var newSrc = '';
      var doubleSrc = '';
      // Loop over each part of the SRC, looking for the Borealis part
      $.each(src, function(index, value){
        if (value.indexOf('borealis_') != -1) {
          // Strip all possible Borealis extensions
          style_name = value.replace('_respondsmall', '');
          style_name = style_name.replace('_respondmedium', '');
          style_name = style_name.replace('_respondlarge', '');
          style_name = style_name.replace('_respondxl', '');
          
          // Determine if we're replacing with the regular sized image
          //  or the double sized image for 2x Pixel Desnity Screens
          var replace_name = ''
          if (dpr < 2)  {
            replace_name = style_name + '_' + regularSize;
          }
          else {
            replace_name = style_name + '_' + doubleSize;
          }
          
          // Append Replacement Name onto New SRC.
          newSrc += '/' + replace_name;
        }
        else {
          // Append whatever the current SRC item is onto New SRC.
          newSrc += '/' + value;
        }
      });
      // New SRC starts with a /, get rid of that.
      newSrc = newSrc.substr(1);
      // Add New SRC to Image, this swapping the image.
      obj.attr('src', newSrc);
    }
  }
});